﻿using System;
using System.Collections;
using System.ComponentModel;
using System.Globalization;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Media;

namespace ListBoxWithButtons
{
    public partial class Page : UserControl
    {
        public Page()
        {
            InitializeComponent();
        }

        private void Add_Click(object sender, RoutedEventArgs e)
        {
            // Get sender Button
            Button b = sender as Button;
            // Get Product via Button's DataContext
            Product p = b.DataContext as Product;
            // Update quantity
            p.Quantity++;
        }

        private void Remove_Click(object sender, RoutedEventArgs e)
        {
            // Same as Add_Click
            Button b = sender as Button;
            Product p = b.DataContext as Product;
            if (0 < p.Quantity)
            {
                p.Quantity--;
            }
        }
    }

    // Simple product definition
    // INotifyPropertyChanged used to provide change notifications
    public class Product : INotifyPropertyChanged
    {
        public string Name { get; set; }

        public Color Color { get; set; }
        // Provide Brush accessor to work around Color binding limitation
        public Brush Brush { get { return new SolidColorBrush(Color); } }

        public int Quantity
        {
            get { return _quantity; }
            set
            {
                _quantity = value;
                // Fire PropertyChanged event to notify listeners of changed value
                var handler = PropertyChanged;
                if (null != handler)
                {
                    handler.Invoke(this, new PropertyChangedEventArgs("Quantity"));
                }
            }
        }
        private int _quantity;

        public event PropertyChangedEventHandler PropertyChanged;
    }

    // Simple user definition contains a simple shopping cart
    public class User
    {
        public IEnumerable ShoppingCart
        {
            get
            {
                return new[] {
                    new Product { Name="Apples", Color=Colors.Red },
                    new Product { Name="Bananas", Color=Colors.Yellow },
                    new Product { Name="Blueberries", Color=Colors.Blue },
                    new Product { Name="Grapes", Color=Colors.Purple },
                    new Product { Name="Oranges", Color=Colors.Orange },
                    new Product { Name="Pears", Color=Colors.Green },
               };
            }
        }
    }

    // Simple IValueConverter returns true iff the value is positive
    // Used to toggle Remove button's IsEnabled when Quantity changes between 0 and 1
    public class IntIsPositive : IValueConverter
    {
        public object Convert(object value, Type targetType, object parameter, CultureInfo culture)
        {
            return (0 < ((int)value));
        }
        public object ConvertBack(object value, Type targetType, object parameter, CultureInfo culture)
        {
            throw new NotImplementedException();
        }
    }
}
